==============
Code Reference
==============

:mod:`guacamole.core`
=====================

.. automodule:: guacamole.core
	:members: Ingredient, Context, Bowl

:mod:`guacamole.recipes`
========================

.. automodule:: guacamole.recipes
	:members:

:mod:`guacamole.recipes.cmd`
============================

.. automodule:: guacamole.recipes.cmd
	:members:

:mod:`guacamole.ingredients`
============================

.. automodule:: guacamole.ingredients
	:members:
	
:mod:`guacamole.ingredients.cmdtree`
====================================

.. automodule:: guacamole.ingredients.cmdtree
	:members:

:mod:`guacamole.ingredients.argparse`
=====================================

.. automodule:: guacamole.ingredients.argparse
	:members:
	
:mod:`guacamole.ingredients.crash`
==================================

.. automodule:: guacamole.ingredients.crash
	:members:

:mod:`guacamole.ingredients.ansi`
=================================

.. automodule:: guacamole.ingredients.ansi
	:members:
